@@ -1,16 +1,16 @@
 from fastapi import APIRouter, Depends
 
 from fief import schemas
-from fief.dependencies.admin_session import get_admin_session_token
+from fief.dependencies.admin_authentication import is_authenticated_admin
 from fief.dependencies.pagination import PaginatedObjects
 from fief.dependencies.tenant import get_paginated_tenants
 from fief.models import Tenant
 from fief.schemas.generics import PaginatedResults
 
-router = APIRouter(dependencies=[Depends(get_admin_session_token)])
+router = APIRouter(dependencies=[Depends(is_authenticated_admin)])
 
 
-@router.get("/")
+@router.get("/", response_model=PaginatedResults[schemas.tenant.Tenant])
 async def list_tenants(
     paginated_tenants: PaginatedObjects[Tenant] = Depends(get_paginated_tenants),
 ) -> PaginatedResults[schemas.tenant.Tenant]:
