@@ -1,8 +1,10 @@
 from fief.tasks.base import SendTask, send_task
+from fief.tasks.forgot_password import on_after_forgot_password
 from fief.tasks.register import on_after_register
 
 __all__ = [
     "send_task",
     "SendTask",
+    "on_after_forgot_password",
     "on_after_register",
 ]
